@@ -1,6 +1,7 @@
 from copy import copy
 from datetime import datetime, timedelta
 from itertools import groupby
+from typing import Optional
 from urllib.parse import quote as urlquote
 
 # import requests  # we use lazy imports to improve load time for local commands
@@ -10,6 +11,7 @@ from tqdm import tqdm
 
 from kks.util.h2t import HTML2Text
 
+
 CONTEST_ID_BY_GROUP = {
     int('19' + str(i)): 130 + i
     for i in range(1, 12)
@@ -84,6 +86,24 @@ class Problem(SummaryProblem):
         return FullProblem(self, page)
 
 
+class ProblemWithDeadline:
+    def __init__(self, problem, contest):
+        self._problem = problem
+        self._contest = contest
+
+    def deadline_is_close(self):
+        return self._contest.deadlines.is_close()
+
+    def deadline_color(self):
+        return self._contest.deadline_color()
+
+    def deadline_string(self):
+        return self._contest.deadlines.format_soft()
+
+    def __getattr__(self, name):
+        return getattr(self._problem, name)
+
+
 class CacheKeys:
     @staticmethod
     def penalty(contest):
@@ -163,7 +183,7 @@ class Report:
 
 
 class TaskScore:
-    def __init__(self, contest, score, status):
+    def __init__(self, contest: str, score: Optional[str], status: str):
         self.contest = contest
         self.score = score
         self.status = status
@@ -232,14 +252,34 @@ class Standings:
 
 
 class Deadlines:
+    FORMAT = '%Y/%m/%d %H:%M:%S MSK'
+    PLACEHOLDER = '----/--/-- --:--:-- MSK (!)'
+
     def __init__(self, soft, hard):
         self.soft = soft
         self.hard = hard
 
+    def is_close(self):
+        from kks.util.storage import Config
+        if self.soft is None:
+            return False
+        dt = self.soft - datetime.now()
+        return dt < timedelta(days=Config().options.deadline_warning_days)
+
+    def format_soft(self):
+        deadline = self.soft
+        if deadline is None:
+            return 'No deadline'
+        result = deadline.strftime(Deadlines.FORMAT)
+        if self.is_close():
+            result += ' (!)'
+        return result
+
+
 
 class ProblemInfo:
     """Subset of task info table used for max score estimation"""
-    def __init__(self, full_score, run_penalty, current_penalty, deadlines):
+    def __init__(self, full_score: int, run_penalty: int, current_penalty: int, deadlines: Deadlines):
         self.full_score = full_score
         self.run_penalty = run_penalty
         self.current_penalty = current_penalty
@@ -249,6 +289,23 @@ class ProblemInfo:
         return self.deadlines.hard is not None and datetime.now() > self.deadlines.hard or self.current_penalty >= self.full_score
 
 
+class ContestInfo:
+    def __init__(self, name, first_problem):
+        self.name = name
+        self.first_problem = first_problem
+
+    def deadline_color(self):
+        if self.past_deadline():
+            return 'red'
+        if self.deadlines.soft is None:
+            return 'green'
+        if self.deadlines.is_close():
+            return 'bright_yellow'
+        return 'yellow'
+
+    def __getattr__(self, name):
+        return getattr(self.first_problem, name)
+
 class FullProblem(SummaryProblem):
     keep_info = ['Time limit:', 'Real time limit:', 'Memory limit:']
 
@@ -284,7 +341,7 @@ class FullProblem(SummaryProblem):
         if output_title is not None:
             output_data = output_title.find_next('pre').text
 
-        return input_data, output_data 
+        return input_data, output_data
 
     @staticmethod
     def parse_statement(html):
@@ -533,7 +590,30 @@ def ejudge_report(link, session):
     return Report(comments, tests)
 
 
-def update_cached_problems(cache, names, session, only_contests=False, summary=None):
+def get_contest_deadlines(session, summary, no_cache):
+    from kks.util.storage import Cache
+
+    names = [problem.short_name for problem in summary]
+
+    contest_names = []
+    first_problems = []
+    for contest, problems in groupby(summary, lambda problem: problem.contest()):
+        contest_names.append(contest)
+        first_problems.append(next(problems).short_name)
+
+    with Cache('problem_info', compress=True, version=PROBLEM_INFO_VERSION).load() as cache:
+        if no_cache:
+            for problem in summary:
+                cache.erase(CacheKeys.deadline(problem.contest()))
+
+        problems = update_cached_problems(cache, names, session, problems=first_problems, summary=summary)
+
+    return [ContestInfo(name, problem) for name, problem in zip(contest_names, problems)]
+
+
+def update_cached_problems(cache, names, session, problems=None, summary=None):
+    # names - latest list of problem names
+    # problems - names of problems to be updated
 
     def cached_problem(problem):
         return BaseProblem(problem.short_name, problem.href)
@@ -545,11 +625,8 @@ def update_cached_problems(cache, names, session, only_contests=False, summary=N
         problem_list = [cached_problem(p) for p in problem_list]
         cache.set('problem_links', problem_list)
 
-    if only_contests:
-        first_problems = []
-        for contest, problems in groupby(problem_list, lambda problem: problem.contest()):
-            first_problems.append(next(problems))
-            problem_list = first_problems
+    if problems is not None:
+        problem_list = [problem for problem in problem_list if problem.short_name in problems]
 
     with tqdm(total=len(problem_list), leave=False) as pbar:
         def with_progress(func, *args, **kwargs):
